# Credits

This project is owned by Geometric Data Analytics, Inc

See [LICENSE](LICENSE) for legal requirements.

Contact Abraham D. Smith <abraham.smith@geomdata.com> Geometric Data Analytics, Inc
for alternative licensing options.

## Development Lead

* Abraham D. Smith <abraham.smith@geomdata.com>

## Contributors

* None yet. Why not be the first?
